==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/MethodPAG.h <==
// public final class soot.jimple.spark.pag.MethodPAG

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6a0a312d99248648 soot_jimple_spark_pag_AbstractMethodPAG
// @dep_class e81dc22c9a7d20bc soot_jimple_spark_pag_MethodPAG

// header file dependencies
// @dep_header soot_jimple_spark_pag_AbstractMethodPAG

#include "soot/jimple/spark/pag/AbstractMethodPAG.h"

#ifndef _JC_soot_jimple_spark_pag_MethodPAG_H_
#define _JC_soot_jimple_spark_pag_MethodPAG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_util_queue_ChunkedQueue$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$sub_refs	_jc_soot_jimple_spark_pag_MethodPAG$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs	_jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$refs	_jc_soot_jimple_spark_pag_MethodPAG$refs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$nonrefs	_jc_soot_jimple_spark_pag_MethodPAG$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$object	_jc_soot_jimple_spark_pag_MethodPAG$object;

typedef const struct _jc_soot_jimple_spark_pag_MethodPAG$vmethods	_jc_soot_jimple_spark_pag_MethodPAG$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_MethodPAG$vtable	_jc_soot_jimple_spark_pag_MethodPAG$vtable;
typedef const struct _jc_soot_jimple_spark_pag_MethodPAG$vtype	_jc_soot_jimple_spark_pag_MethodPAG$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$_init$e68ac3c8474690fb(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addInEdge$147f322639d85338(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addInternalEdge$83772423f9a409fd(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addOutEdge$c50c62aacb4b694c(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addToPAG$c5e73feed4d81666(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_jimple_spark_pag_AbstractPAG$object *_jc_soot_jimple_spark_pag_MethodPAG$method$pag$6efce07fced0c20a(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addInEdge$147f322639d85338;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addInternalEdge$83772423f9a409fd;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addOutEdge$c50c62aacb4b694c;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addToPAG$c5e73feed4d81666;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$pag$6efce07fced0c20a;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_MethodPAG$vmethods {
	void	(*addInEdge$147f322639d85338)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
	void	(*addInternalEdge$83772423f9a409fd)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
	void	(*addOutEdge$c50c62aacb4b694c)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
	void	(*addToPAG$c5e73feed4d81666)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*(*pag$6efce07fced0c20a)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_MethodPAG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_AbstractMethodPAG$vmethods	soot_jimple_spark_pag_AbstractMethodPAG;
	_jc_soot_jimple_spark_pag_MethodPAG$vmethods	soot_jimple_spark_pag_MethodPAG;
};

// Vtype
struct _jc_soot_jimple_spark_pag_MethodPAG$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_MethodPAG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_MethodPAG$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_object	*addedContexts;
	struct _jc_soot_util_queue_ChunkedQueue$object	*internalEdges;
	struct _jc_soot_util_queue_ChunkedQueue$object	*inEdges;
	struct _jc_soot_util_queue_ChunkedQueue$object	*outEdges;
	struct _jc_soot_util_queue_QueueReader$object	*internalReader;
	struct _jc_soot_util_queue_QueueReader$object	*inReader;
	struct _jc_soot_util_queue_QueueReader$object	*outReader;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_MethodPAG$refs {
    _jc_soot_jimple_spark_pag_MethodPAG$sub_refs	soot_jimple_spark_pag_MethodPAG;
    _jc_soot_jimple_spark_pag_AbstractMethodPAG$sub_refs	soot_jimple_spark_pag_AbstractMethodPAG;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_MethodPAG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_AbstractMethodPAG$sub_nonrefs	soot_jimple_spark_pag_AbstractMethodPAG;
    _jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs	soot_jimple_spark_pag_MethodPAG;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_MethodPAG$object {
	_jc_soot_jimple_spark_pag_MethodPAG$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_MethodPAG$vtype	*vtype;
	_jc_soot_jimple_spark_pag_MethodPAG$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_MethodPAG$vtype _jc_soot_jimple_spark_pag_MethodPAG$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_MethodPAG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_MethodPAG$class_object;

#endif	/* _JC_soot_jimple_spark_pag_MethodPAG_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/MethodPAG.h <==
// public final class soot.jimple.spark.pag.MethodPAG

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6a0a312d99248648 soot_jimple_spark_pag_AbstractMethodPAG
// @dep_class e81dc22c9a7d20bc soot_jimple_spark_pag_MethodPAG

// header file dependencies
// @dep_header soot_jimple_spark_pag_AbstractMethodPAG

#include "soot/jimple/spark/pag/AbstractMethodPAG.h"

#ifndef _JC_soot_jimple_spark_pag_MethodPAG_H_
#define _JC_soot_jimple_spark_pag_MethodPAG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_util_queue_ChunkedQueue$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$sub_refs	_jc_soot_jimple_spark_pag_MethodPAG$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs	_jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$refs	_jc_soot_jimple_spark_pag_MethodPAG$refs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$nonrefs	_jc_soot_jimple_spark_pag_MethodPAG$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_MethodPAG$object	_jc_soot_jimple_spark_pag_MethodPAG$object;

typedef const struct _jc_soot_jimple_spark_pag_MethodPAG$vmethods	_jc_soot_jimple_spark_pag_MethodPAG$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_MethodPAG$vtable	_jc_soot_jimple_spark_pag_MethodPAG$vtable;
typedef const struct _jc_soot_jimple_spark_pag_MethodPAG$vtype	_jc_soot_jimple_spark_pag_MethodPAG$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$_init$e68ac3c8474690fb(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addInEdge$147f322639d85338(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addInternalEdge$83772423f9a409fd(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addOutEdge$c50c62aacb4b694c(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_MethodPAG$method$addToPAG$c5e73feed4d81666(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_pag_AbstractPAG$object *_jc_soot_jimple_spark_pag_MethodPAG$method$pag$6efce07fced0c20a(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addInEdge$147f322639d85338;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addInternalEdge$83772423f9a409fd;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addOutEdge$c50c62aacb4b694c;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$addToPAG$c5e73feed4d81666;
extern _jc_method _jc_soot_jimple_spark_pag_MethodPAG$method_info$pag$6efce07fced0c20a;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_MethodPAG$vmethods {
	void	(*addInEdge$147f322639d85338)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
	void	(*addInternalEdge$83772423f9a409fd)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
	void	(*addOutEdge$c50c62aacb4b694c)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
	void	(*addToPAG$c5e73feed4d81666)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*(*pag$6efce07fced0c20a)(_jc_env *, struct _jc_soot_jimple_spark_pag_MethodPAG$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_MethodPAG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_AbstractMethodPAG$vmethods	soot_jimple_spark_pag_AbstractMethodPAG;
	_jc_soot_jimple_spark_pag_MethodPAG$vmethods	soot_jimple_spark_pag_MethodPAG;
};

// Vtype
struct _jc_soot_jimple_spark_pag_MethodPAG$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_MethodPAG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_MethodPAG$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_object	*addedContexts;
	struct _jc_soot_util_queue_ChunkedQueue$object	*internalEdges;
	struct _jc_soot_util_queue_ChunkedQueue$object	*inEdges;
	struct _jc_soot_util_queue_ChunkedQueue$object	*outEdges;
	struct _jc_soot_util_queue_QueueReader$object	*internalReader;
	struct _jc_soot_util_queue_QueueReader$object	*inReader;
	struct _jc_soot_util_queue_QueueReader$object	*outReader;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_MethodPAG$refs {
    _jc_soot_jimple_spark_pag_MethodPAG$sub_refs	soot_jimple_spark_pag_MethodPAG;
    _jc_soot_jimple_spark_pag_AbstractMethodPAG$sub_refs	soot_jimple_spark_pag_AbstractMethodPAG;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_MethodPAG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_AbstractMethodPAG$sub_nonrefs	soot_jimple_spark_pag_AbstractMethodPAG;
    _jc_soot_jimple_spark_pag_MethodPAG$sub_nonrefs	soot_jimple_spark_pag_MethodPAG;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_MethodPAG$object {
	_jc_soot_jimple_spark_pag_MethodPAG$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_MethodPAG$vtype	*vtype;
	_jc_soot_jimple_spark_pag_MethodPAG$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_MethodPAG$vtype _jc_soot_jimple_spark_pag_MethodPAG$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_MethodPAG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_MethodPAG$class_object;

#endif	/* _JC_soot_jimple_spark_pag_MethodPAG_H_ */
